
/* eslint-disable @typescript-eslint/no-var-requires */
require('dotenv').config()

export enum ENV {
	'development' = 'development',
	'production' = 'production',
	'deploy' = 'deploy',
	'test' = 'test',
}

export type OPTIONS = {
	[key in ENV]: {
		database: string
		username: string
		password: string
		host: string
		port: number
	}
}

export const Options: OPTIONS = {
	[ENV.development]: {
		username: process.env.DATABASE_USERNAME as string || 'root',
		password: process.env.DATABASE_PASSWORD as string || 'admin',
		database: process.env.DATABASE as string || 'auxilio_cultural',
		host: process.env.DATABASE_HOST as string || 'localhost',
		port: process.env.DATABASE_PORT as unknown as number || 3306,
	},
	[ENV.production]: {
		username: process.env.DATABASE_USERNAME as string,
		password: process.env.DATABASE_PASSWORD as string,
		database: process.env.DATABASE as string,
		host: process.env.DATABASE_HOST as string,
		port: process.env.DATABASE_PORT as unknown as number,
	},
	[ENV.test]: {
		database: process.env.DATABASE as string || 'test',
		username: process.env.DATABASE_USERNAME as string || 'root',
		password: process.env.DATABASE_PASSWORD as string || 'admin',
		host: process.env.DATABASE_HOST as string || 'localhost',
		port: process.env.DATABASE_PORT as unknown as number || 3306,
	},
	[ENV.deploy]: {
		username: process.env.DATABASE_USERNAME as string || 'root',
		password: process.env.DATABASE_PASSWORD as string || 'admin',
		database: process.env.DATABASE as string || 'auxilio_cultural',
		host: process.env.DATABASE_HOST as string || 'localhost',
		port: process.env.DATABASE_PORT as unknown as number || 3306,
	},
}


export default Options[process.env.NODE_ENV || ENV.test]
