import { Optional } from 'sequelize'
import { Table, Column, Model, DataType } from 'sequelize-typescript'

import { IModelDocProject } from '@/types/models'

type IModelCreationAttributes = Optional<IModelDocProject, 'id'>

@Table({
	tableName: 'doc_projeto',
	freezeTableName: true,
	updatedAt: false,
	createdAt: false,
	underscored: true,
})
class ModelDocProject
	extends Model<IModelDocProject, IModelCreationAttributes>
	implements IModelDocProject
{
	@Column({
		autoIncrement: true,
		primaryKey: true,
		type: DataType.INTEGER({ length: 11 }),
		allowNull: false,
	})
	id: number

	@Column({
		type: DataType.INTEGER({ length: 11 }),
		allowNull: false,
		field: 'id_projeto',
	})
	idProject: number

	@Column({
		type: DataType.STRING(32),
		allowNull: false,
		field: 'arquivo',
	})
	file: string

	@Column({
		type: DataType.STRING(40),
		allowNull: false,
		field: 'dataCadastro',
	})
	createdAt?: string

	@Column({
		type: DataType.STRING(100),
		allowNull: false,
		field: 'nome',
	})
	name: string

	@Column({
		type: DataType.INTEGER({ length: 2 }),
		allowNull: false,
		field: 'tipo',
	})
	type: number

	@Column({
		type: DataType.STRING(10),
		allowNull: false,
		field: 'tipo_arquivo',
	})
	typeFile: string

	@Column({
		type: DataType.STRING(300),
		allowNull: false,
		field: 'link',
	})
	link: string

	@Column({
		type: DataType.BOOLEAN,
		allowNull: false,
		field: 'atualizou',
	})
	updated: boolean
}

export default ModelDocProject
