import { Optional } from 'sequelize'
import { Table, Column, Model, DataType } from 'sequelize-typescript'

import { IModelDocuments } from '@/types/models'

type IModelCreationAttributes = Optional<IModelDocuments, 'id'>

@Table({
	tableName: 'documentacao',
	freezeTableName: true,
	updatedAt: false,
	createdAt: false,
	underscored: true,
})
class ModelDocuments
	extends Model<IModelDocuments, IModelCreationAttributes>
	implements IModelDocuments
{
	@Column({
		type: DataType.INTEGER({ length: 11 }),
		allowNull: false,
		primaryKey: true,
		autoIncrement: true,
		field: 'id',
	})
	public id: number

	@Column({
		type: DataType.INTEGER({ length: 11 }),
		allowNull: false,
		defaultValue: 0,
		field: 'id_usuario',
	})
	public idUser: number

	
	@Column({
		type: DataType.STRING(300),
		allowNull: true,
		field: 'arquivo',
		defaultValue: 'Não informado',
	})
	public file: string

	
	@Column({
		type: DataType.STRING(40),
		allowNull: true,
		field: 'data',
		defaultValue: null,
	})
	public date?: string

	@Column({
		type: DataType.STRING(14),
		allowNull: true,
		field: 'cpf',
		defaultValue: null,
	})
	public document: number

	
	@Column({
		type: DataType.INTEGER({ length: 11 }),
		allowNull: false,
		defaultValue: 1,
		field: 'tipo',
	})
	public type: number

	@Column({
		type: DataType.STRING(100),
		allowNull: false,
		field: 'descricao',
		defaultValue: 'Sem descrição',
	})
	public description: string


	@Column({
		type: DataType.STRING(300),
		allowNull: false,
		field: 'link',
		defaultValue: 'Não informado',
	})
	public filePath: string
	@Column({
		type: DataType.STRING(10),
		allowNull: true,
		defaultValue: 0,
		field: 'numero_inscricao',
		comment: 'Numero de inscrição do edital para o qual ele enviou o arquivo '
	})
	public numberInscription: string

	@Column({
		type: DataType.DATE,
		allowNull: false,
		field: 'data_cadastro',
		defaultValue: DataType.NOW,
	})
	public createdAt: string

	@Column({
		type: DataType.STRING(10),
		allowNull: true,
		field: 'tipo_arquivo',
		defaultValue: 'PDF',
	})
	public typeFile: string

	@Column({
		type: DataType.SMALLINT({ length: 1 }),
		allowNull: true,
		field: 'atualizou',
		defaultValue: 0,
	})
	public updated: boolean
}

export default ModelDocuments
