import { Optional } from 'sequelize'
import { Table, Column, Model, DataType, AfterFind } from 'sequelize-typescript'

import { IModelProject } from '@/types/models'

type IModelCreationAttributes = Optional<IModelProject, 'id'>

@Table({
	tableName: 'projeto',
	freezeTableName: true,
	updatedAt: false,
	createdAt: false,
	underscored: true,
})
class ModelProject
	extends Model<IModelProject, IModelCreationAttributes>
	implements IModelProject
{
	@Column({
		autoIncrement: true,
		primaryKey: true,
		type: DataType.INTEGER({ length: 11 }),
		allowNull: false,
	})
	id: number

	@Column({
		type: DataType.INTEGER({ length: 11 }),
		allowNull: false,
		field: 'id_usuario',
	})
	idUser: number

	@Column({
		type: DataType.STRING(14),
		allowNull: false,
		field: 'cpf',
	})
	cpf: string

	@Column({
		type: DataType.STRING(200),
		allowNull: false,
		field: 'nome_projeto',
	})
	nameProject: string

	@Column({
		type: DataType.STRING(7500),
		allowNull: false,
		field: 'resumo_projeto',
	})
	summaryProject: string

	@Column({
		type: DataType.STRING(7500),
		allowNull: false,
		field: 'descricao_projeto',
	})
	aboutProject: string

	@Column({
		type: DataType.STRING(200),
		allowNull: false,
		field: 'tipo_projeto',
	})
	typeProject: string

	@Column({
		type: DataType.STRING(200),
		allowNull: false,
		field: 'url_projeto',
	})
	urlProject: string

	@Column({
		type: DataType.DATE,
		allowNull: false,
		field: 'data_inicio',
	})
	dateStart: Date

	@Column({
		type: DataType.DATE,
		allowNull: false,
		field: 'data_fim',
	})
	dateEnd: Date

	@Column({
		type: DataType.STRING(5),
		allowNull: false,
		field: 'hora_final',
	})
	hourEnd: string

	@Column({
		type: DataType.INTEGER({ length: 2 }),
		allowNull: false,
		field: 'status',
	})
	status: number

	@Column({
		type: DataType.STRING(20),
		allowNull: false,
		field: 'data_cadastro',
	})
	createdAt: string

	@Column({
		type: DataType.STRING(20),
		allowNull: false,
		field: 'data_atualizacao',
	})
	updateAt: string

	@Column({
		type: DataType.INTEGER({ length: 2 }),
		allowNull: false,
		field: 'tipo_pes_fis_jur',
	})
	type: number

	@Column({
		type: DataType.STRING(200),
		allowNull: false,
		field: 'orgao',
	})
	company: string

	@Column({
		type: DataType.STRING(150),
		allowNull: false,
		field: 'cidade',
	})
	city: string

	@Column({
		type: DataType.INTEGER({ length: 11 }),
		allowNull: false,
		field: 'qtd_vagas',
	})
	amountOfVacancies: number

	@Column({
		type: DataType.INTEGER({ length: 11 }),
		allowNull: false,
		field: 'permissao_inscricao',
	})
	amountOfEnrollment: number

	@Column({
		type: DataType.STRING(200),
		allowNull: false,
		field: 'recurso_financeiro',
	})
	financialResource: string

	@Column({
		type: DataType.STRING(4),
		allowNull: false,
		field: 'ano_lancamento',
	})
	yearRelease: string

	@AfterFind
	static async securityCPF(instance: ModelProject) {
		instance.cpf = '***.***.***-**'
	}
}

export default ModelProject
