import { Optional } from 'sequelize'
import { Table, Column, Model, DataType } from 'sequelize-typescript'

import { IModelUser } from '@/types/models'

/**
 * `usuario` (
  `id` int(11) NOT NULL,
  `cpf` varchar(20) COLLATE utf8mb3_unicode_ci NOT NULL COMMENT 'nick name',
  `cpf_cnpj` varchar(20) COLLATE utf8mb3_unicode_ci NOT NULL DEFAULT '0' COMMENT 'CPF ou  CNPJ de quem é o responsável pelo o cadastro.',
  `cpf_representado` varchar(20) COLLATE utf8mb3_unicode_ci NOT NULL DEFAULT '0' COMMENT 'cpf de quem está sendo representado',
  `possui_rep` varchar(20) COLLATE utf8mb3_unicode_ci NOT NULL DEFAULT 'Não' COMMENT 'informa se o cadastro foi feito para representar alguém ou não',
  `email` varchar(200) COLLATE utf8mb3_unicode_ci NOT NULL,
  `nome` varchar(300) COLLATE utf8mb3_unicode_ci NOT NULL,
  `tipo` varchar(200) COLLATE utf8mb3_unicode_ci NOT NULL,
  `cidade` varchar(100) COLLATE utf8mb3_unicode_ci DEFAULT 'Não informado',
  `senha` varchar(32) COLLATE utf8mb3_unicode_ci NOT NULL,
  `tipoAcesso` varchar(2) COLLATE utf8mb3_unicode_ci DEFAULT '4',
  `dataCadastro` varchar(60) COLLATE utf8mb3_unicode_ci NOT NULL,
  `dataAtualizacao` varchar(60) COLLATE utf8mb3_unicode_ci NOT NULL,
  `contaValida` int(2) DEFAULT 0,
  `chaveAcesso` varchar(200) COLLATE utf8mb3_unicode_ci NOT NULL,
  `ip_utilizado` varchar(100) COLLATE utf8mb3_unicode_ci DEFAULT '0.0.0.0',
  `qtd_acessos` int(4) NOT NULL DEFAULT 0,
  `atualizado_adm` int(4) NOT NULL DEFAULT 0,
  `id_validado` int(1) NOT NULL DEFAULT 0,
  `tipo_user` int(1) DEFAULT 1,
  `setor` varchar(200) COLLATE utf8mb3_unicode_ci DEFAULT 'Não alocado a um setor',
  `orgao` varchar(300) COLLATE utf8mb3_unicode_ci DEFAULT 'Não alocado a um órgão',
  `migrado` varchar(4) COLLATE utf8mb3_unicode_ci DEFAULT 'Não',
  `id_migrado` int(1) DEFAULT 1,
  `coluna_controle_docs` int(1) NOT NULL DEFAULT 0,
  `sessao` int(1) NOT NULL DEFAULT 0 COMMENT 'define se o usuário está online ou não',
  `data_ultimo_acesso` timestamp NOT NULL DEFAULT current_timestamp(),
  `ativo` int(1) NOT NULL DEFAULT 1,
  `data_que_fez_logof` timestamp NOT NULL DEFAULT current_timestamp(),
  `id_orgao` int(11) NOT NULL DEFAULT 0
)
 */

type IModelCreationAttributes = Optional<IModelUser, 'id'>

@Table({
	tableName: 'usuario',
	freezeTableName: true,
	updatedAt: false,
	createdAt: false,
	underscored: true,
})

class ModelUser
	extends Model<IModelUser, IModelCreationAttributes>
	implements IModelUser
{
    representative: string
    typeAccess: string
    idValidated: number
    typeUser: number
    idMigrated: number
    columnControlDocs: number
    dateLastAccess: string
    dateLogout: string
    idAgency: number
    @Column({
		autoIncrement: true,
		primaryKey: true,
		type: DataType.INTEGER({ length: 11 }),
		allowNull: false,
	})
	id: number

    @Column({
        type: DataType.STRING(20),
        allowNull: false,
        field: 'cpf',
    })
    cpf: string

    @Column({
        type: DataType.STRING(20),
        allowNull: false,
        field: 'cpf_cnpj',
    })
    cpf_cnpj: string

    @Column({
        type: DataType.STRING(20),
        allowNull: false,
        field: 'cpf_representado',
    })
    cpfRepresented

    @Column({
        type: DataType.STRING(20),
        allowNull: false,
        field: 'possui_rep',
    })
    hasRepresentative: string

    @Column({
        type: DataType.STRING(200),
        allowNull: false,
        field: 'email',
    })
    email: string

    @Column({
        type: DataType.STRING(300),
        allowNull: false,
        field: 'nome',
    })
    name: string

    @Column({
        type: DataType.STRING(200),
        allowNull: false,
        field: 'tipo',
    })
    type: string

    @Column({
        type: DataType.STRING(100),
        allowNull: false,
        field: 'cidade',
    })
    city: string

    @Column({
        type: DataType.STRING(32),
        allowNull: false,
        field: 'senha',
    })
    password: string

    @Column({
        type: DataType.STRING(2),
        allowNull: false,
        field: 'tipoAcesso',
    })
    accessType: string

    @Column({
        type: DataType.STRING(60),
        allowNull: false,
        field: 'dataCadastro',
    })
    dateRegister: string

    @Column({
        type: DataType.STRING(60),
        allowNull: false,
        field: 'dataAtualizacao',
    })
    dateUpdate: string

    @Column({
        type: DataType.INTEGER({ length: 2 }),
        allowNull: false,
        field: 'contaValida',
    })
    validAccount: number

    @Column({
        type: DataType.STRING(200),
        allowNull: false,
        field: 'chaveAcesso',
    })
    accessKey: string

    @Column({
        type: DataType.STRING(100),
        allowNull: false,
        field: 'ip_utilizado',
    })
    ipUsed: string

    @Column({
        type: DataType.INTEGER({ length: 4 }),
        allowNull: false,
        field: 'qtd_acessos',
    })
    accessCount: number

    @Column({
        type: DataType.INTEGER({ length: 4 }),
        allowNull: false,
        field: 'atualizado_adm',
    })
    updatedByAdmin: number

    @Column({
        type: DataType.INTEGER({ length: 1 }),
        allowNull: false,
        field: 'id_validado',
    })
    validatedId: number

    @Column({
        type: DataType.INTEGER({ length: 1 }),
        allowNull: false,
        field: 'tipo_user',
    })
    userType: number

    @Column({
        type: DataType.STRING(200),
        allowNull: false,
        field: 'setor',
    })
    sector: string

    @Column({
        type: DataType.STRING(300),
        allowNull: false,
        field: 'orgao',
    })
    agency: string

    @Column({
        type: DataType.STRING(4),
        allowNull: false,
        field: 'migrado',
    })
    migrated: string

    @Column({
        type: DataType.INTEGER({ length: 1 }),
        allowNull: false,
        field: 'id_migrado',
    })
    migratedId: number

    @Column({
        type: DataType.INTEGER({ length: 1 }),
        allowNull: false,
        field: 'coluna_controle_docs',
    })
    documentControlColumn: number

    @Column({
        type: DataType.INTEGER({ length: 1 }),
        allowNull: false,
        field: 'sessao',
    })
    session: number

    @Column({
        type: DataType.DATE,
        allowNull: false,
        field: 'data_ultimo_acesso',
    })
    lastAccessDate: Date

    @Column({
        type: DataType.INTEGER({ length: 1 }),
        allowNull: false,
        field: 'ativo',
    })
    active: number

    @Column({
        type: DataType.DATE,
        allowNull: false,
        field: 'data_que_fez_logof',
    })
    dateOfLogoff: Date

    @Column({
        type: DataType.INTEGER({ length: 11 }),
        allowNull: false,
        field: 'id_orgao',
    })
    agencyId: number
}

	
export default ModelUser